==> marketplace-constants-0.1.4.9.tar.gz: marketplace-constants-0.1.4.9/mpconstants/regions/nn_NO.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Dei sameinte arabiske emiratane',
 u'af': u'Afghanistan',
 u'ag': u'Antigua og Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Dei nederlandske Antillane',
 u'ao': u'Angola',
 u'aq': u'Antarktika',
 u'ar': u'Argentina',
 u'as': u'Amerikansk Samoa',
 u'at': u'Austerrike',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'\\u00c5land Islands',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia og Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'Belgia',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\\u00e9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brasil',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Bouvet\xf8ya',
 u'bw': u'Botswana',
 u'by': u'Kviterussland',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Kokos\xf8yane',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Den sentralafrikanske republikken',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Sveits',
 u'ci': u'Elfenbeinskysten',
 u'ck': u'Cook\xf8yane',
 u'cl': u'Chile',
 u'cm': u'Kamerun',
 u'cn': u'Kina',
 u'co': u'Colombia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cape Verde',
 u'cx': u'Christmas\xf8ya',
 u'cy': u'Kypros',
 u'cz': u'Tsjekkia',
 u'de': u'Tyskland',
 u'dj': u'Djibouti',
 u'dk': u'Danmark',
 u'dm': u'Dominica',
 u'do': u'Dominikanske Republikk',
 u'dz': u'Algerie',
 u'ec': u'Ecuador',
 u'ee': u'Estland',
 u'eg': u'Egypt',
 u'eh': u'Vest-Sahara',
 u'er': u'Eritrea',
 u'es': u'Spania',
 u'et': u'Etiopia',
 u'fi': u'Finland',
 u'fj': u'Fiji',
 u'fk': u'Falklands\xf8yane',
 u'fm': u'Mikronesiaf\xf8derasjonen',
 u'fo': u'F\xe6r\xf8yane',
 u'fr': u'Frankrike',
 u'ga': u'Gabon',
 u'gb': u'Storbritannia',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Fransk Guyana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Gr\xf8nland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Ekvatorial-Guinea',
 u'gr': u'Hellas',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard- og McDonald\xf8yane',
 u'hn': u'Honduras',
 u'hr': u'Croatia',
 u'ht': u'Haiti',
 u'hu': u'Ungarn',
 u'id': u'Indonesia',
 u'ie': u'Irland',
 u'il': u'Israel',
 u'im': u'Isle of Man',
 u'in': u'India',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Island',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jordan',
 u'jp': u'Japan',
 u'ke': u'Kenya',
 u'kg': u'Kirgisistan',
 u'kh': u'Kambodsja',
 u'ki': u'Kiribati',
 u'km': u'Komorane',
 u'kn': u'St. Kitts og Nevis',
 u'kp': u'Nord-Korea',
 u'kr': u'S\xf8r-Korea',
 u'kw': u'Kuwait',
 u'ky': u'Cayman\xf8yane',
 u'kz': u'Kasakhstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lithuania',
 u'lu': u'Luxenbourg',
 u'lv': u'Latvia',
 u'ly': u'Libya',
 u'ma': u'Marokko',
 u'mc': u'Monaco',
 u'md': u'Moldova, republikken',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshall\xf8yane',
 u'mk': u'Makedonia',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Nord-Marianane',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Maldivane',
 u'mw': u'Malawi',
 u'mx': u'Mexico',
 u'my': u'Malaysia',
 u'mz': u'Mosambik',
 u'na': u'Namibia',
 u'nc': u'New Caledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolk Island',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Nederland',
 u'no': u'Noreg',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'New Zealand',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Fransk Polynesia',
 u'pg': u'Papua Ny-Guinea',
 u'ph': u'Filippinane',
 u'pk': u'Pakistan',
 u'pl': u'Polen',
 u'pm': u'Saint-Pierre-et-Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Palestinske territorium',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'Reunion',
 u'ro': u'Romania',
 u'rs': u'Serbia',
 u'ru': u'Russland',
 u'rw': u'Rwanda',
 u'sa': u'Saudi Arabia',
 u'sb': u'Salomon\xf8yane',
 u'sc': u'Seychellane',
 u'sd': u'Sudan',
 u'se': u'Sverige',
 u'sg': u'Singapore',
 u'sh': u'St. Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard og Jan Mayen',
 u'sk': u'Slovakia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Surinam',
 u'st': u'S\xe3o Tom\xe9 og Pr\xedncipe',
 u'sv': u'El Salvador',
 u'sy': u'Syria',
 u'sz': u'Swaziland',
 u'tc': u'Turks- og Caicos\xf8yane',
 u'td': u'Tsjad',
 u'tf': u'Dei franske s\xf8rterritoria',
 u'tg': u'Togo',
 u'th': u'Thailand',
 u'tj': u'Tadsjikistan',
 u'tk': u'Tokelau',
 u'tl': u'Aust-Timor',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Tyrkia',
 u'tt': u'Trinidad og Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ukraina',
 u'ug': u'Uganda',
 u'um': u'USAs ytre sm\xe5\xf8yar',
 u'us': u'USA',
 u'uy': u'Uruguay',
 u'uz': u'Usbekistan',
 u'va': u'Vatikanstaten',
 u'vc': u'St. Vincent og Grenadinane',
 u've': u'Venezuela',
 u'vg': u'Jomfru\xf8yane (Storbritannia)',
 u'vi': u'Jomfru\xf8yane (USA)',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis- og Futuna\xf8yane',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'S\xf8r-Afrika',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}

==> marketplace-constants-0.3.1.tar.gz: marketplace-constants-0.3.1/mpconstants/regions/nn_NO.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Dei sameinte arabiske emiratane',
 u'af': u'Afghanistan',
 u'ag': u'Antigua og Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Dei nederlandske Antillane',
 u'ao': u'Angola',
 u'aq': u'Antarktika',
 u'ar': u'Argentina',
 u'as': u'Amerikansk Samoa',
 u'at': u'Austerrike',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'\xc5land Islands',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia og Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'Belgia',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brasil',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Bouvet\xf8ya',
 u'bw': u'Botswana',
 u'by': u'Kviterussland',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Kokos\xf8yane',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Den sentralafrikanske republikken',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Sveits',
 u'ci': u'Elfenbeinskysten',
 u'ck': u'Cook\xf8yane',
 u'cl': u'Chile',
 u'cm': u'Kamerun',
 u'cn': u'Kina',
 u'co': u'Colombia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cape Verde',
 u'cx': u'Christmas\xf8ya',
 u'cy': u'Kypros',
 u'cz': u'Tsjekkia',
 u'de': u'Tyskland',
 u'dj': u'Djibouti',
 u'dk': u'Danmark',
 u'dm': u'Dominica',
 u'do': u'Dominikanske Republikk',
 u'dz': u'Algerie',
 u'ec': u'Ecuador',
 u'ee': u'Estland',
 u'eg': u'Egypt',
 u'eh': u'Vest-Sahara',
 u'er': u'Eritrea',
 u'es': u'Spania',
 u'et': u'Etiopia',
 u'fi': u'Finland',
 u'fj': u'Fiji',
 u'fk': u'Falklands\xf8yane',
 u'fm': u'Mikronesiaf\xf8derasjonen',
 u'fo': u'F\xe6r\xf8yane',
 u'fr': u'Frankrike',
 u'ga': u'Gabon',
 u'gb': u'Storbritannia',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Fransk Guyana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Gr\xf8nland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Ekvatorial-Guinea',
 u'gr': u'Hellas',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard- og McDonald\xf8yane',
 u'hn': u'Honduras',
 u'hr': u'Croatia',
 u'ht': u'Haiti',
 u'hu': u'Ungarn',
 u'id': u'Indonesia',
 u'ie': u'Irland',
 u'il': u'Israel',
 u'im': u'Isle of Man',
 u'in': u'India',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Island',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jordan',
 u'jp': u'Japan',
 u'ke': u'Kenya',
 u'kg': u'Kirgisistan',
 u'kh': u'Kambodsja',
 u'ki': u'Kiribati',
 u'km': u'Komorane',
 u'kn': u'St. Kitts og Nevis',
 u'kp': u'Nord-Korea',
 u'kr': u'S\xf8r-Korea',
 u'kw': u'Kuwait',
 u'ky': u'Cayman\xf8yane',
 u'kz': u'Kasakhstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lithuania',
 u'lu': u'Luxenbourg',
 u'lv': u'Latvia',
 u'ly': u'Libya',
 u'ma': u'Marokko',
 u'mc': u'Monaco',
 u'md': u'Moldova, republikken',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshall\xf8yane',
 u'mk': u'Makedonia',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Nord-Marianane',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Maldivane',
 u'mw': u'Malawi',
 u'mx': u'Mexico',
 u'my': u'Malaysia',
 u'mz': u'Mosambik',
 u'na': u'Namibia',
 u'nc': u'New Caledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolk Island',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Nederland',
 u'no': u'Noreg',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'New Zealand',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Fransk Polynesia',
 u'pg': u'Papua Ny-Guinea',
 u'ph': u'Filippinane',
 u'pk': u'Pakistan',
 u'pl': u'Polen',
 u'pm': u'Saint-Pierre-et-Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Palestinske territorium',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'Reunion',
 u'ro': u'Romania',
 u'rs': u'Serbia',
 u'ru': u'Russland',
 u'rw': u'Rwanda',
 u'sa': u'Saudi Arabia',
 u'sb': u'Salomon\xf8yane',
 u'sc': u'Seychellane',
 u'sd': u'Sudan',
 u'se': u'Sverige',
 u'sg': u'Singapore',
 u'sh': u'St. Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard og Jan Mayen',
 u'sk': u'Slovakia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Surinam',
 u'st': u'S\xe3o Tom\xe9 og Pr\xedncipe',
 u'sv': u'El Salvador',
 u'sy': u'Syria',
 u'sz': u'Swaziland',
 u'tc': u'Turks- og Caicos\xf8yane',
 u'td': u'Tsjad',
 u'tf': u'Dei franske s\xf8rterritoria',
 u'tg': u'Togo',
 u'th': u'Thailand',
 u'tj': u'Tadsjikistan',
 u'tk': u'Tokelau',
 u'tl': u'Aust-Timor',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Tyrkia',
 u'tt': u'Trinidad og Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ukraina',
 u'ug': u'Uganda',
 u'um': u'USAs ytre sm\xe5\xf8yar',
 u'us': u'USA',
 u'uy': u'Uruguay',
 u'uz': u'Usbekistan',
 u'va': u'Vatikanstaten',
 u'vc': u'St. Vincent og Grenadinane',
 u've': u'Venezuela',
 u'vg': u'Jomfru\xf8yane (Storbritannia)',
 u'vi': u'Jomfru\xf8yane (USA)',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis- og Futuna\xf8yane',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'S\xf8r-Afrika',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}
